@@ -37,6 +37,7 @@ class InterconnectAttachment(object):
       'bps-10g': 'BPS_10G',
       'bps-20g': 'BPS_20G',
       'bps-50g': 'BPS_50G',
+      'bps-100g': 'BPS_100G',
       '50m': 'BPS_50M',
       '100m': 'BPS_100M',
       '200m': 'BPS_200M',
@@ -49,6 +50,7 @@ class InterconnectAttachment(object):
       '10g': 'BPS_10G',
       '20g': 'BPS_20G',
       '50g': 'BPS_50G',
+      '100g': 'BPS_100G',
   }
 
   _EDGE_AVAILABILITY_DOMAIN_CONVERSION = {
@@ -92,6 +94,7 @@ class InterconnectAttachment(object):
       cloud_router_ipv6_interface_id,
       customer_router_ipv6_interface_id,
       subnet_length,
+      multicast_enabled,
   ):
     """Make an interconnect attachment insert request."""
     interconnect_self_link = None
@@ -134,6 +137,8 @@ class InterconnectAttachment(object):
       attachment.customerRouterIpv6InterfaceId = customer_router_ipv6_interface_id
     if subnet_length is not None:
       attachment.subnetLength = subnet_length
+    if multicast_enabled is not None:
+      attachment.multicastEnabled = multicast_enabled
 
     if validate_only is not None:
       return (self._client.interconnectAttachments, 'Insert',
@@ -161,6 +166,7 @@ class InterconnectAttachment(object):
       customer_router_ipv6_interface_id=None,
       labels=None,
       label_fingerprint=None,
+      multicast_enabled=None,
   ):
     """Make an interconnect attachment patch request."""
     interconnect_attachment = self._messages.InterconnectAttachment(
@@ -191,6 +197,8 @@ class InterconnectAttachment(object):
       interconnect_attachment.customerRouterIpv6InterfaceId = (
           customer_router_ipv6_interface_id
       )
+    if multicast_enabled is not None:
+      interconnect_attachment.multicastEnabled = multicast_enabled
     return (self._client.interconnectAttachments, 'Patch',
             self._messages.ComputeInterconnectAttachmentsPatchRequest(
                 project=self.ref.project,
@@ -236,6 +244,7 @@ class InterconnectAttachment(object):
       cloud_router_ipv6_interface_id=None,
       customer_router_ipv6_interface_id=None,
       subnet_length=None,
+      multicast_enabled=None,
       only_generate_request=False,
       validate_only=None,
   ):
@@ -287,6 +296,7 @@ class InterconnectAttachment(object):
             cloud_router_ipv6_interface_id,
             customer_router_ipv6_interface_id,
             subnet_length,
+            multicast_enabled,
         )
     ]
     if not only_generate_request:
@@ -312,6 +322,7 @@ class InterconnectAttachment(object):
       customer_router_ipv6_interface_id=None,
       only_generate_request=False,
       mtu=None,
+      multicast_enabled=None,
   ):
     """Patch an interconnectAttachment."""
     if bandwidth:
@@ -339,6 +350,7 @@ class InterconnectAttachment(object):
             customer_router_ipv6_interface_id,
             labels,
             label_fingerprint,
+            multicast_enabled,
         )
     ]
     if not only_generate_request:
