@@ -77,6 +77,7 @@ class Client:
       parent,
       forwarding_rule,
       intercept_deployment_group,
+      description,
       deployment_id=None,
       labels=None,
   ):
@@ -89,6 +90,7 @@ class Client:
         "projects/myproj/regions/us-central1/forwardingRules/my-rule"
       intercept_deployment_group: The deployment group of the deployment, e.g.
         "projects/myproj/locations/global/interceptDeploymentGroups/my-group"
+      description: The description of the deployment.
       deployment_id: The ID of the deployment, e.g. "my-deployment".
       labels: A dictionary with the labels of the deployment.
 
@@ -101,6 +103,10 @@ class Client:
         interceptDeploymentGroup=intercept_deployment_group,
         labels=labels,
     )
+    # TODO(b/381836581): Remove this check once the field is
+    # available in V1.
+    if hasattr(deployment, 'description'):
+      deployment.description = description
 
     create_request = self.messages.NetworksecurityProjectsLocationsInterceptDeploymentsCreateRequest(
         interceptDeployment=deployment,
@@ -119,12 +125,14 @@ class Client:
   def UpdateDeployment(
       self,
       name,
+      description,
       update_fields,
   ):
     """Calls the UpdateInterceptDeployment API.
 
     Args:
       name: The name of the deployment.
+      description: The description of the deployment.
       update_fields: A dictionary of the fields to update mapped to their new
         values.
 
@@ -134,6 +142,11 @@ class Client:
     deployment = self.messages.InterceptDeployment(
         labels=update_fields.get('labels', None),
     )
+    # TODO(b/381836581): Remove this check once the field is
+    # available in V1.
+    if hasattr(deployment, 'description'):
+      deployment.description = description
+
     update_request = self.messages.NetworksecurityProjectsLocationsInterceptDeploymentsPatchRequest(
         name=name,
         interceptDeployment=deployment,
