@@ -30,22 +30,38 @@ def MakeFutureReservationMessageFromArgs(messages, resources, args,
                                               getattr(args, 'local_ssd', None))
   accelerators = reservation_util.MakeGuestAccelerators(
       messages, getattr(args, 'accelerator', None))
+
   allocated_instance_properties = MakeAllocatedInstanceProperties(
-      messages, args.machine_type, args.min_cpu_platform, local_ssds,
-      accelerators, getattr(args, 'location_hint', None),
+      messages,
+      args.machine_type,
+      args.min_cpu_platform,
+      local_ssds,
+      accelerators,
+      getattr(args, 'location_hint', None),
       getattr(args, 'maintenance_freeze_duration', None),
-      getattr(args, 'maintenance_interval', None))
+      getattr(args, 'maintenance_interval', None),
+  )
+
   source_instance_template_ref = (
       reservation_util.ResolveSourceInstanceTemplate(args, resources)
       if getattr(args, 'source_instance_template', None)
       else None
   )
+
   sku_properties = MakeSpecificSKUPropertiesMessage(
       messages,
       allocated_instance_properties,
       args.total_count,
       source_instance_template_ref,
   )
+
+  aggregate_reservation_properties = MakeAggregateReservationPropertiesMessage(
+      messages,
+      getattr(args, 'tpu_version', None),
+      getattr(args, 'tpu_count', None),
+      getattr(args, 'workload_type', None),
+  )
+
   time_window = MakeTimeWindowMessage(messages, args.start_time,
                                       getattr(args, 'end_time', None),
                                       getattr(args, 'duration', None))
@@ -98,10 +114,11 @@ def MakeFutureReservationMessageFromArgs(messages, resources, args,
   return MakeFutureReservationMessage(
       messages,
       future_reservation_ref.Name(),
-      sku_properties,
       time_window,
       share_settings,
       planning_status,
+      aggregate_reservation_properties,
+      sku_properties,
       enable_auto_delete_reservations,
       auto_created_reservations_delete_time,
       auto_created_reservations_duration,
@@ -123,6 +140,9 @@ def MakeAllocatedInstanceProperties(messages,
                                     freeze_duration=None,
                                     freeze_interval=None):
   """Constructs an instance propteries for reservations message object."""
+  if machine_type is None:
+    return None
+
   prop_msgs = (
       messages.AllocationSpecificSKUAllocationReservedInstanceProperties)
   instance_properties = prop_msgs(
@@ -147,7 +167,10 @@ def MakeSpecificSKUPropertiesMessage(
     total_count,
     source_instance_template_ref=None,
 ):
-  """Constructs a specific sku properties message object."""
+  """Constructs a specific sku properties message object if any is specified."""
+  if instance_properties is None and source_instance_template_ref is None:
+    return None
+
   properties = None
   source_instance_template_url = None
   if source_instance_template_ref:
@@ -160,6 +183,49 @@ def MakeSpecificSKUPropertiesMessage(
       instanceProperties=properties)
 
 
+def MakeAggregateReservationPropertiesMessage(
+    messages, tpu_version, tpu_count, workload_type
+):
+  """Constructs an aggregate reservation properties message object."""
+  if not tpu_version:
+    return None
+
+  # Static mapping of TPU version to VM family.
+  tpu_version_to_vm_family = {
+      'V5E': (
+          messages.AllocationAggregateReservation.VmFamilyValueValuesEnum.VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP
+      ),
+      'V5P': (
+          messages.AllocationAggregateReservation.VmFamilyValueValuesEnum.VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P
+      ),
+      'V6E': (
+          messages.AllocationAggregateReservation.VmFamilyValueValuesEnum.VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E
+      )
+      }
+
+  reserved_resources = []
+  accelerator = (
+      messages.AllocationAggregateReservationReservedResourceInfoAccelerator(
+          acceleratorCount=tpu_count,
+      )
+  )
+  reserved_resources.append(
+      messages.AllocationAggregateReservationReservedResourceInfo(
+          accelerator=accelerator
+      )
+  )
+  aggregate_reservation_properties = messages.AllocationAggregateReservation(
+      vmFamily=messages.AllocationAggregateReservation.VmFamilyValueValuesEnum(
+          tpu_version_to_vm_family[tpu_version]
+      ),
+      reservedResources=reserved_resources,
+      workloadType=messages.AllocationAggregateReservation.WorkloadTypeValueValuesEnum(
+          workload_type
+      ),
+  )
+  return aggregate_reservation_properties
+
+
 def MakeTimeWindowMessage(messages, start_time, end_time, duration):
   """Constructs the time window message object."""
   if end_time:
@@ -280,10 +346,11 @@ def MakeReservationMode(messages, reservation_mode):
 def MakeFutureReservationMessage(
     messages,
     future_reservation_name,
-    sku_properties,
     time_window,
     share_settings,
     planning_status,
+    aggregate_reservation_properties=None,
+    sku_properties=None,
     enable_auto_delete_reservations=None,
     auto_created_reservations_delete_time=None,
     auto_created_reservations_duration=None,
@@ -297,9 +364,17 @@ def MakeFutureReservationMessage(
   """Constructs a future reservation message object."""
   future_reservation_message = messages.FutureReservation(
       name=future_reservation_name,
-      specificSkuProperties=sku_properties,
       timeWindow=time_window,
-      planningStatus=planning_status)
+      planningStatus=planning_status,
+  )
+
+  if aggregate_reservation_properties:
+    future_reservation_message.aggregateReservation = (
+        aggregate_reservation_properties
+    )
+  if sku_properties:
+    future_reservation_message.specificSkuProperties = sku_properties
+
   if share_settings:
     future_reservation_message.shareSettings = share_settings
 
