@@ -231,6 +231,27 @@ def GetDeleteAfterDurationFlag():
   )
 
 
+def AddScopeFlags(parser):
+  """Adds scope flag to the parser."""
+  parser.add_argument(
+      '--scope',
+      metavar='SCOPE',
+      type=lambda x: x.lower(),
+      choices={
+          'all': 'Perform maintenance on all hosts in the reservation.',
+          'running': (
+              'Perform maintenance only on the hosts in the reservation that'
+              ' have running VMs.'
+          ),
+          'unused': (
+              'Perform maintenance only on the hosts in the reservation that'
+              " don't have running VMs."
+          ),
+      },
+      help='The maintenance scope to set for the reservation.',
+  )
+
+
 def GetDisableAutoDelete():
   """Gets the --disable-auto-delete flag."""
   help_text = """\
@@ -270,18 +291,84 @@ def GetSourceInstanceTemplateFlag(custom_name=None):
 def GetReservationSharingPolicyFlag(custom_name=None):
   """Gets the --reservation-sharing-policy flag."""
   help_text = """\
-  The reservation sharing policy to use for this reservation. If set to
-  allow_all, the reservation can be shared with first party services. If this
-  flag is ommited, the default value will be disallow_all.
+  The reservation sharing policy to use for this reservation.
   """
   return base.Argument(
       custom_name or '--reservation-sharing-policy',
-      choices=['allow_all', 'disallow_all'],
+      type=lambda x: x.upper(),
+      choices={
+          'ALLOW_ALL': (
+              'The reservation can be shared with Google Cloud services.'
+          ),
+          'DISALLOW_ALL': (
+              "The reservation won't be shared with Google Cloud services. If"
+              ' you omit this flag during creation, the default value is'
+              ' DISALLOW_ALL.'
+          ),
+      },
       help=help_text,
-      hidden=True,
   )
 
 
+def GetTpuVersion(required=True):
+  """Gets the --tpu-version flag."""
+  help_text = """\
+  The version of Cloud TPU to reserve.
+  """
+  return base.Argument(
+      '--tpu-version',
+      type=lambda x: x.upper(),
+      choices={
+          'V5E': 'Cloud TPU v5e Lite',
+          'V5P': 'Cloud TPU v5p',
+          'V6E': 'Cloud TPU v6e',
+      },
+      required=required,
+      help=help_text,
+  )
+
+
+def GetTpuCount(required=False):
+  """Gets the --tpu-count flag."""
+  help_text = """\
+  The number of TPUs to reserve.
+  """
+  return base.Argument(
+      '--tpu-count', type=int, required=required, help=help_text
+  )
+
+
+def GetWorkloadType(required=False):
+  """Gets the --workload-type flag."""
+  help_text = """\
+  The workload type of the TPU reservation.
+  """
+  return base.Argument(
+      '--workload-type',
+      type=lambda x: x.upper(),
+      choices={
+          'SERVING': (
+              'Reserved resources will be optimized for SERVING workloads, such'
+              ' as ML inference'
+          ),
+          'BATCH': (
+              'Reserved resources will be optimized for BATCH workloads, such'
+              ' as ML training.'
+          ),
+      },
+      required=required,
+      help=help_text,
+  )
+
+
+def GetAcceleratorType(required=True):
+  """Gets the --accelerator-type flag."""
+  help_text = """\
+  The accelerator type to use for this reservation.
+  """
+  return base.Argument('--accelerator-type', required=required, help=help_text)
+
+
 def AddCreateFlags(
     parser,
     support_fleet=False,
