@@ -267,6 +267,17 @@ class ServicesClient(metaclass=ServicesClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/services/(?P<service>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def worker_pool_path(project: str,location: str,worker_pool: str,) -> str:
+        """Returns a fully-qualified worker_pool string."""
+        return "projects/{project}/locations/{location}/workerPools/{worker_pool}".format(project=project, location=location, worker_pool=worker_pool, )
+
+    @staticmethod
+    def parse_worker_pool_path(path: str) -> Dict[str,str]:
+        """Parses a worker_pool path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/workerPools/(?P<worker_pool>.+?)$", path)
+        return m.groupdict() if m else {}
+
     @staticmethod
     def common_billing_account_path(billing_account: str, ) -> str:
         """Returns a fully-qualified billing_account string."""
