@@ -46,12 +46,17 @@ CONNECTION_PORT = '9600'
 
 # Regional ISPAC Constants and Templates
 
-REGIONAL_SERIAL_PORT_GATEWAY_TEMPLATE = '{0}-ssh-serialport.googleapis.com'
+REGIONAL_SERIAL_PORT_GATEWAY_TEMPLATE = '{0}-ssh-serialport.{1}'
+
 REGIONAL_HOST_KEY_URL_TEMPLATE = (
     'https://www.gstatic.com/vm_serial_port/{0}/{0}.pub'
 )
+REGIONAL_HOST_KEY_URL_TEMPLATE_V2 = (
+    'https://www.gstatic.com/vm_serial_port_public_keys/{0}/{0}.pub'
+)
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class ConnectToSerialPort(base.Command):
   """Connect to the serial port of an instance.
@@ -78,6 +83,7 @@ class ConnectToSerialPort(base.Command):
   """
 
   category = base.TOOLS_CATEGORY
+  use_v2_host_key_endpoint = False
 
   @staticmethod
   def Args(parser):
@@ -91,8 +97,11 @@ class ConnectToSerialPort(base.Command):
     parser.add_argument(
         '--dry-run',
         action='store_true',
-        help=('If provided, the ssh command is printed to standard out '
-              'rather than being executed.'))
+        help=(
+            'If provided, the ssh command is printed to standard out '
+            'rather than being executed.'
+        ),
+    )
 
     parser.add_argument(
         'user_host',
@@ -103,7 +112,8 @@ class ConnectToSerialPort(base.Command):
 
         ``USER'' specifies the username to authenticate as. If omitted,
         the current OS user is selected.
-        """)
+        """,
+    )
 
     parser.add_argument(
         '--port',
@@ -114,7 +124,8 @@ class ConnectToSerialPort(base.Command):
         Instances can support up to four serial ports. By default, this
         command will connect to the first serial port. Setting this flag
         will connect to the requested serial port.
-        """)
+        """,
+    )
 
     parser.add_argument(
         '--extra-args',
@@ -125,7 +136,8 @@ class ConnectToSerialPort(base.Command):
         Optional arguments can be passed to the serial port connection by
         passing key-value pairs to this flag, such as max-connections=N or
         replay-lines=N. See {0} for additional options.
-        """.format(SERIAL_PORT_HELP))
+        """.format(SERIAL_PORT_HELP),
+    )
 
     parser.add_argument(
         '--location',
@@ -136,9 +148,8 @@ class ConnectToSerialPort(base.Command):
     )
 
     flags.AddZoneFlag(
-        parser,
-        resource_type='instance',
-        operation_type='connect to')
+        parser, resource_type='instance', operation_type='connect to'
+    )
 
     ssh_utils.AddSSHKeyExpirationArgs(parser)
 
@@ -149,14 +160,16 @@ class ConnectToSerialPort(base.Command):
 
     ssh_helper = ssh_utils.BaseSSHHelper()
     ssh_helper.Run(args)
-    ssh_helper.keys.EnsureKeysExist(args.force_key_file_overwrite,
-                                    allow_passphrase=True)
+    ssh_helper.keys.EnsureKeysExist(
+        args.force_key_file_overwrite, allow_passphrase=True
+    )
 
     remote = ssh.Remote.FromArg(args.user_host)
     if not remote:
       raise ssh_utils.ArgumentError(
           'Expected argument of the form [USER@]INSTANCE. Received [{0}].'
-          .format(args.user_host))
+          .format(args.user_host)
+      )
     if not remote.user:
       remote.user = ssh.GetDefaultSshUsername()
     public_key = ssh_helper.keys.GetPublicKey().ToEntry(include_comment=True)
@@ -176,36 +189,70 @@ class ConnectToSerialPort(base.Command):
     else:
       location = args.location
 
-    gateway = REGIONAL_SERIAL_PORT_GATEWAY_TEMPLATE.format(location)
+    gateway = REGIONAL_SERIAL_PORT_GATEWAY_TEMPLATE.format(
+        location, properties.GetUniverseDomain()
+    )
     hostkey_url = REGIONAL_HOST_KEY_URL_TEMPLATE.format(location)
+    hostkey_url_v2 = REGIONAL_HOST_KEY_URL_TEMPLATE_V2.format(location)
     log.info('Connecting to serialport via server in {0}'.format(location))
 
     hostname = '[{0}]:{1}'.format(gateway, CONNECTION_PORT)
     # Update google_compute_known_hosts file with published host key
-    http_client = http.Http()
     known_hosts = ssh.KnownHosts.FromDefaultFile()
-    http_response = http_client.request(hostkey_url)
 
-    if int(http_response[0]['status']) == httplib.OK:
-      host_key = encoding.Decode(http_response[1]).strip()
-      known_hosts.Add(hostname, host_key, overwrite=True)
+    def _GetHostKey(endpoint):
+      """Get host key from endpoint."""
+      http_client = http.Http()
+      host_keys = []
+      http_response = http_client.request(endpoint)
+      log.info('http_response: {0}'.format(http_response))
+      if int(http_response[0]['status']) == httplib.OK:
+        # There can be multiple public host keys for the same region,
+        # in the response separated by newlines.
+        retrieved_host_keys = (
+            encoding.Decode(http_response[1]).strip().split('\n')
+        )
+        for host_key in retrieved_host_keys:
+          host_keys.append(host_key)
+        log.info(
+            'Successfully acquired hostkey for {0} from {1}'.format(
+                gateway, endpoint
+            )
+        )
+      else:
+        log.warning(
+            'Failed to acquire hostkey for {0} from {1}'.format(
+                gateway, endpoint
+            )
+        )
+      return host_keys
+
+    host_keys = []
+    if self.use_v2_host_key_endpoint:
+      host_keys.extend(_GetHostKey(hostkey_url_v2))
+    host_keys.extend(_GetHostKey(hostkey_url))
+
+    if host_keys:
+      if self.use_v2_host_key_endpoint:
+        known_hosts.AddMultiple(hostname, host_keys, overwrite=True)
+      else:
+        known_hosts.Add(hostname, host_keys[0], overwrite=True)
       known_hosts.Write()
-      log.info('Successfully acquired hostkey for {0}'.format(gateway))
+      log.info('Successfully written hostkey for {0}'.format(gateway))
     elif known_hosts.ContainsAlias(hostname):
       log.warning(
-          'Unable to download and update Host Key for [{0}] from [{1}]. '
-          'Attempting to connect using existing Host Key in [{2}]. If '
-          'the connection fails, please try again to update the Host '
-          'Key.'.format(gateway, hostkey_url, known_hosts.file_path)
+          'Unable to download and update Host Key for [{0}]'
+          ' . Attempting to connect using existing Host Key in [{1}]. If'
+          ' the connection fails, please try again to update the Host Key.'
+          .format(gateway, known_hosts.file_path)
       )
     else:
       log.warning(
-          'Unable to download Host Key for [{0}] from [{1}]. No Host Key found'
-          ' in known_hosts file [{2}]. gcloud does not have a fallback Host Key'
-          ' and will therefore terminate the connection attempt. If the problem'
-          ' persists, try updating gcloud and connecting again.'.format(
-              gateway, hostkey_url, known_hosts.file_path
-          )
+          'Unable to download Host Key for [{0}]. No Host'
+          ' Key found in known_hosts file [{1}]. gcloud does not have a'
+          ' fallback Host Key and will therefore terminate the connection'
+          ' attempt. If the problem persists, try updating gcloud and'
+          ' connecting again.'.format(gateway, known_hosts.file_path)
       )
       # We shouldn't allow a connection without the correct host key
       return
@@ -221,7 +268,8 @@ class ConnectToSerialPort(base.Command):
         public_key,
         expiration_micros,
         self.ReleaseTrack(),
-        messages=holder.client.messages)
+        messages=holder.client.messages,
+    )
     remote.user = oslogin_state.user
 
     # Determine the serial user, host tuple (remote)
@@ -248,23 +296,28 @@ class ConnectToSerialPort(base.Command):
     options = ssh_helper.GetConfig(hostname, strict_host_key_checking='yes')
     del options['HostKeyAlias']
     options['ControlPath'] = 'none'
-    cmd = ssh.SSHCommand(serial_remote, identity_file=identity_file,
-                         port=CONNECTION_PORT,
-                         options=options)
+    cmd = ssh.SSHCommand(
+        serial_remote,
+        identity_file=identity_file,
+        port=CONNECTION_PORT,
+        options=options,
+    )
     if args.dry_run:
       log.out.Print(' '.join(cmd.Build(ssh_helper.env)))
       return
     if not oslogin_state.oslogin_enabled:
       ssh_helper.EnsureSSHKeyExists(
-          client, remote.user, instance, project, expiration)
+          client, remote.user, instance, project, expiration
+      )
 
     # TODO(b/35355795): Don't force connect in general.
     # At a minimum, avoid injecting 'y' if PuTTY will prompt for a 2FA
     # authentication method (since we know that won't work), or if the user has
     # disabled the property.
     putty_force_connect = (
-        not oslogin_state.oslogin_2fa_enabled and
-        properties.VALUES.ssh.putty_force_connect.GetBool())
+        not oslogin_state.oslogin_2fa_enabled
+        and properties.VALUES.ssh.putty_force_connect.GetBool()
+    )
 
     # Don't wait for the instance to become SSHable. We are not connecting to
     # the instance itself through SSH, so the instance doesn't need to have
@@ -273,8 +326,8 @@ class ConnectToSerialPort(base.Command):
     # that causes ssh to exit with 255.
     try:
       return_code = cmd.Run(
-          ssh_helper.env,
-          putty_force_connect=putty_force_connect)
+          ssh_helper.env, putty_force_connect=putty_force_connect
+      )
     except ssh.CommandError:
       return_code = 255
     if return_code:
@@ -310,4 +363,5 @@ class ConnectToSerialPortAlphaBeta(ConnectToSerialPort):
 
   @classmethod
   def Args(cls, parser):
+    cls.use_v2_host_key_endpoint = True
     super(ConnectToSerialPortAlphaBeta, cls).Args(parser)
