@@ -26,6 +26,7 @@ from googlecloudsdk.command_lib.compute.interconnects.attachments import flags a
 from googlecloudsdk.command_lib.util.args import labels_util
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class Update(base.UpdateCommand):
   """Update a Compute Engine dedicated interconnect attachment.
@@ -78,9 +79,11 @@ class Update(base.UpdateCommand):
         customer_router_ipv6_interface_id=getattr(
             args, 'customer_router_ipv6_interface_id', None
         ),
+        multicast_enabled=getattr(args, 'enable_multicast', None),
     )
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
 class UpdateBeta(Update):
   """Update a Compute Engine dedicated interconnect attachment.
@@ -126,9 +129,11 @@ class UpdateBeta(Update):
         customer_router_ipv6_interface_id=getattr(
             args, 'customer_router_ipv6_interface_id', None
         ),
+        multicast_enabled=getattr(args, 'enable_multicast', None),
     )
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class UpdateAlpha(UpdateBeta):
   """Update a Compute Engine dedicated interconnect attachment.
@@ -141,3 +146,4 @@ class UpdateAlpha(UpdateBeta):
   @classmethod
   def Args(cls, parser):
     super(UpdateAlpha, cls).Args(parser)
+    attachment_flags.AddEnableMulticast(parser, update=True)
