@@ -24,9 +24,8 @@ from googlecloudsdk.command_lib.kms import flags
 from googlecloudsdk.core import resources
 
 
-@base.Hidden
 @base.UniverseCompatible
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class KeyHandles(base.Group):
   """Create and manage key-handles.
 
