@@ -18,7 +18,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-from googlecloudsdk.api_lib.network_security.security_profiles.threat_prevention import sp_api
+from googlecloudsdk.api_lib.network_security.security_profiles import tpp_api
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.network_security import sp_flags
 from googlecloudsdk.command_lib.util.args import labels_util
@@ -26,6 +26,31 @@ from googlecloudsdk.core import exceptions as core_exceptions
 from googlecloudsdk.core import log
 
 DETAILED_HELP = {
+    'DESCRIPTION': """
+          To delete existing antivirus, severities, or threat-ids of
+          threat prevention profile.
+          Check the updates of update-override command by using `gcloud network-security
+          security-profiles threat-prevention list-override my-security-profile`.
+
+          For more examples, refer to the EXAMPLES section below.
+
+        """,
+    'EXAMPLES': """
+            To delete an override, run:
+
+              $ {command} my-security-profile --severities=MEDIUM
+
+            `my-security-profile` is the name of the Security Profile in the
+            format organizations/{organizationID}/locations/{location}/securityProfiles/
+            {security_profile_id}
+            where organizationID is the organization ID to which the changes should apply,
+            location - `global` specified and
+            security_profile_id the Security Profile Identifier
+
+        """,
+}
+
+DETAILED_HELP_NO_ANTIVIRUS = {
     'DESCRIPTION': """
           To delete existing severities or threat-ids of
           threat prevention profile.
@@ -51,16 +76,21 @@ DETAILED_HELP = {
 }
 
 
-@base.ReleaseTracks(
-    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
-)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class DeleteOverride(base.UpdateCommand):
   """Delete overrides of Threat Prevention Profile."""
 
+  enable_antivirus = False
+
   @classmethod
   def Args(cls, parser):
     sp_flags.AddSecurityProfileResource(parser, cls.ReleaseTrack())
-    sp_flags.AddSeverityorThreatIDArg(parser, required=True)
+    # TODO: b/384033890 - Remove this check once the field is
+    # available in BETA and GA (and b/379282262 is fixed).
+    sp_flags.AddSeverityorThreatIDorAntivirusArg(
+        parser, required=True, enable_antivirus=cls.enable_antivirus
+    )
     labels_util.AddUpdateLabelsFlags(parser)
     base.ASYNC_FLAG.AddToParser(parser)
     base.ASYNC_FLAG.SetDefault(parser, False)
@@ -69,7 +99,7 @@ class DeleteOverride(base.UpdateCommand):
     return client.GetSecurityProfile(security_profile.RelativeName()).labels
 
   def Run(self, args):
-    client = sp_api.Client(self.ReleaseTrack())
+    client = tpp_api.Client(self.ReleaseTrack())
     security_profile = args.CONCEPTS.security_profile.Parse()
     is_async = args.async_
 
@@ -85,9 +115,15 @@ class DeleteOverride(base.UpdateCommand):
     elif args.IsSpecified('threat_ids'):
       update_mask = 'threatOverrides'
       overrides = args.threat_ids
+    # TODO: b/384033890 - Remove this check once the field is
+    # available in BETA and GA (and b/379282262 is fixed).
+    elif args.IsSpecified('antivirus') and self.enable_antivirus:
+      update_mask = 'antivirusOverrides'
+      overrides = args.antivirus
     else:
       raise core_exceptions.Error(
-          'Either --severities or --threat-ids must be specified'
+          'Either --antivirus, --severities, or --threat-ids  must be'
+          ' specified'
       )
 
     if args.location != 'global':
@@ -100,6 +136,7 @@ class DeleteOverride(base.UpdateCommand):
         overrides,
         update_mask,
         labels=labels_update.GetOrNone(),
+        enable_antivirus=self.enable_antivirus,
     )
 
     # Return the in-progress operation if async is requested.
@@ -122,4 +159,13 @@ class DeleteOverride(base.UpdateCommand):
     )
 
 
-DeleteOverride.detailed_help = DETAILED_HELP
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.DefaultUniverseOnly
+class DeleteOverrideAlpha(DeleteOverride):
+  """Delete overrides of Threat Prevention Profile."""
+
+  enable_antivirus = True
+
+
+DeleteOverrideAlpha.detailed_help = DETAILED_HELP
+DeleteOverride.detailed_help = DETAILED_HELP_NO_ANTIVIRUS
