@@ -26,6 +26,31 @@ from googlecloudsdk.core import exceptions as core_exceptions
 from googlecloudsdk.core import log
 
 DETAILED_HELP = {
+    'DESCRIPTION': """
+          To update existing antivirus, severities, or threat-ids of
+          threat prevention profile with intended action on each specified.
+          Check the updates of update-override command by using `gcloud network-security
+          security-profiles threat-prevention list-override my-security-profile`.
+
+          For more examples, refer to the EXAMPLES section below.
+
+        """,
+    'EXAMPLES': """
+            To update an override, run:
+
+              $ {command} my-security-profile --severities=MEDIUM --action=ALLOW
+
+            `my-security-profile` is the name of the Security Profile in the
+            format organizations/{organizationID}/locations/{location}/securityProfiles/
+            {security_profile_id}
+            where organizationID is the organization ID to which the changes should apply,
+            location - `global` specified and
+            security_profile_id the Security Profile Identifier
+
+        """,
+}
+
+DETAILED_HELP_NO_ANTIVIRUS = {
     'DESCRIPTION': """
           To update existing severities or threat-ids of
           threat prevention profile with intended action on each specified.
@@ -51,18 +76,24 @@ DETAILED_HELP = {
 }
 
 
-@base.ReleaseTracks(
-    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
-)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 @base.DefaultUniverseOnly
 class UpdateOverride(base.UpdateCommand):
   """Update Overrides of Threat Prevention Profile."""
 
+  enable_antivirus = False
+
   @classmethod
   def Args(cls, parser):
     sp_flags.AddSecurityProfileResource(parser, cls.ReleaseTrack())
-    sp_flags.AddSeverityorThreatIDArg(parser, required=True)
-    sp_flags.AddActionArg(parser, required=True)
+    # TODO: b/384033890 - Remove this check once the field is
+    # available in BETA and GA (and b/379282262 is fixed).
+    sp_flags.AddSeverityorThreatIDorAntivirusArg(
+        parser, required=True, enable_antivirus=cls.enable_antivirus
+    )
+    sp_flags.AddActionArg(
+        parser, required=True, enable_antivirus=cls.enable_antivirus
+    )
     labels_util.AddUpdateLabelsFlags(parser)
     base.ASYNC_FLAG.AddToParser(parser)
     base.ASYNC_FLAG.SetDefault(parser, False)
@@ -98,9 +129,18 @@ class UpdateOverride(base.UpdateCommand):
       action = args.action
       for threat in threats:
         overrides.append({'threatId': threat, 'action': action})
+    # TODO: b/384033890 - Remove this check once the field is
+    # available in BETA and GA (and b/379282262 is fixed).
+    elif args.IsSpecified('antivirus') and self.enable_antivirus:
+      update_mask = 'antivirusOverrides'
+      protocols = args.antivirus
+      action = args.action
+      for protocol in protocols:
+        overrides.append({'protocol': protocol, 'action': action})
     else:
       raise core_exceptions.Error(
-          'Either --severities or --threat-ids must be specified'
+          'Either --antivirus, --severities, or --threat-ids  must be'
+          ' specified'
       )
 
     if args.location != 'global':
@@ -114,6 +154,7 @@ class UpdateOverride(base.UpdateCommand):
         'update_override',
         update_mask,
         labels=labels_update.GetOrNone(),
+        enable_antivirus=self.enable_antivirus,
     )
 
     # Return the in-progress operation if async is requested.
@@ -136,4 +177,13 @@ class UpdateOverride(base.UpdateCommand):
     )
 
 
-UpdateOverride.detailed_help = DETAILED_HELP
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.DefaultUniverseOnly
+class UpdateOverrideAlpha(UpdateOverride):
+  """Update Overrides of Threat Prevention Profile."""
+
+  enable_antivirus = True
+
+
+UpdateOverrideAlpha.detailed_help = DETAILED_HELP
+UpdateOverride.detailed_help = DETAILED_HELP_NO_ANTIVIRUS
