@@ -38,8 +38,9 @@ _INVALID_TIMESTAMP = (
 
 
 # TODO(b/321801975) make command public after suv2 launch.
+@base.UniverseCompatible
 @base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class Get(base.Command):
   """Get consumer policy for a project, folder or organization.
 
