@@ -19,7 +19,7 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.Hidden
+@base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class AnywhereCaches(base.Group):
   """Manage Cloud Storage Anywhere Caches."""
