@@ -28,6 +28,23 @@ from googlecloudsdk.command_lib.storage import user_request_args_factory
 from googlecloudsdk.command_lib.storage.resources import resource_reference
 from googlecloudsdk.command_lib.storage.tasks.buckets import create_bucket_task
 
+_LIFECYCLE_HELP_TEXT = """
+Sets the lifecycle management configuration on a bucket. For example,
+The following lifecycle management configuration JSON document
+specifies that all objects in this bucket that are more than 365 days
+old are deleted automatically:
+
+  {
+    "rule":
+    [
+      {
+        "action": {"type": "Delete"},
+        "condition": {"age": 365}
+      }
+    ]
+  }
+"""
+
 
 @base.UniverseCompatible
 class Create(base.Command):
@@ -139,13 +156,19 @@ class Create(base.Command):
     flags.add_enable_per_object_retention_flag(parser)
     flags.add_recovery_point_objective_flag(parser)
 
+    parser.add_argument(
+        '--enable-hierarchical-namespace',
+        action='store_true',
+        default=None,
+        help=(
+            'Enable hierarchical namespace for the bucket. To use this'
+            ' flag, you must also use --uniform-bucket-level-access'
+        ),
+    )
+
+    parser.add_argument('--lifecycle-file', help=_LIFECYCLE_HELP_TEXT)
+
     if cls.ReleaseTrack() == base.ReleaseTrack.ALPHA:
-      parser.add_argument(
-          '--enable-hierarchical-namespace',
-          action='store_true',
-          help='Enable hierarchical namespace for the bucket. To use this'
-               ' flag, you must also use --uniform-bucket-level-access',
-      )
       flags.add_ip_filter_file_flag(parser)
 
   def Run(self, args):
