@@ -29,10 +29,13 @@ import gslib.tests.testcase as testcase
 from gslib.tests.testcase.integration_testcase import SkipForS3
 from gslib.tests.util import ObjectToURI as suri
 from gslib.tests.util import SequentialAndParallelTransfer
+from gslib.tests.util import SetBotoConfigForTest
+from gslib.tests.util import SetEnvironmentForTest
 from gslib.tests.util import unittest
 from gslib.utils.boto_util import UsingCrcmodExtension
 from gslib.utils.retry_util import Retry
 from gslib.utils.system_util import IS_WINDOWS
+from gslib.utils import shim_util
 
 
 class TestMvUnitTests(testcase.GsUtilUnitTestCase):
@@ -105,6 +108,30 @@ class TestMvUnitTests(testcase.GsUtilUnitTestCase):
     self.assertEqual(actual, expected)
 
 
+class TestMvUnitTestsWithShim(testcase.ShimUnitTestBase):
+  """Unit tests for mv command with shim."""
+
+  def test_shim_translates_flags(self):
+    bucket_uri = self.CreateBucket()
+    fpath = self.CreateTempFile(contents=b'abcd')
+    with SetBotoConfigForTest([('GSUtil', 'use_gcloud_storage', 'True'),
+                               ('GSUtil', 'hidden_shim_mode', 'dry_run')]):
+      with SetEnvironmentForTest({
+          'CLOUDSDK_CORE_PASS_CREDENTIALS_TO_GSUTIL': 'True',
+          'CLOUDSDK_ROOT_DIR': 'fake_dir',
+      }):
+        mock_log_handler = self.RunCommand(
+            'mv', ['-a', 'public-read', fpath,
+                   suri(bucket_uri)],
+            return_log_handler=True)
+        info_lines = '\n'.join(mock_log_handler.messages['info'])
+        self.assertIn(
+            'Gcloud Storage Command: {} storage mv'
+            ' --predefined-acl publicRead {} {}'.format(
+                shim_util._get_gcloud_binary_path('fake_dir'), fpath,
+                suri(bucket_uri)), info_lines)
+
+
 class TestMvE2ETests(testcase.GsUtilIntegrationTestCase):
   """Integration tests for mv command."""
 
